API documentation
=================

The following documentation is based on the source code of version |release| of
the `npm-accel` package.

**Available modules**

.. contents::
   :local:

:mod:`npm_accel`
----------------

.. automodule:: npm_accel
   :members:

:mod:`npm_accel.cli`
--------------------

.. automodule:: npm_accel.cli
   :members:

:mod:`npm_accel.exceptions`
---------------------------

.. automodule:: npm_accel.exceptions
   :members:
